@@ -14,10 +14,6 @@ __version__ = "0.1"
 __author__ = "James Mills, prologic at shortcircuit dot net dot au"
 
 
-from traceback import format_exc
-from xmlrpclib import ServerProxy
-
-
 from circuits.web import XMLRPC as XMLRPCDispatcher
 
 
@@ -39,4 +35,4 @@ class XMLRPC(BasePlugin):
     def init(self, *args, **kwargs):
         super(XMLRPC, self).init(*args, **kwargs)
 
-        XMLRPCDispatcher("/rpc", "utf-8", "rpc").register(self)
+        XMLRPCDispatcher("/xml-rpc", "utf-8", "rpc").register(self)
